# frozen_string_literal: true

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Auto-generated by gapic-generator-ruby. DO NOT EDIT!

require "google/cloud/errors"
require "google/cloud/gaming/v1/game_server_clusters_service_pb"

module Google
  module Cloud
    module Gaming
      module V1
        module GameServerClustersService
          ##
          # Client for the GameServerClustersService service.
          #
          # The game server cluster maps to Kubernetes clusters running Agones and is
          # used to manage fleets within clusters.
          #
          class Client
            include Paths

            # @private
            attr_reader :game_server_clusters_service_stub

            ##
            # Configure the GameServerClustersService Client class.
            #
            # See {::Google::Cloud::Gaming::V1::GameServerClustersService::Client::Configuration}
            # for a description of the configuration fields.
            #
            # ## Example
            #
            # To modify the configuration for all GameServerClustersService clients:
            #
            #     ::Google::Cloud::Gaming::V1::GameServerClustersService::Client.configure do |config|
            #       config.timeout = 10.0
            #     end
            #
            # @yield [config] Configure the Client client.
            # @yieldparam config [Client::Configuration]
            #
            # @return [Client::Configuration]
            #
            def self.configure
              @configure ||= begin
                namespace = ["Google", "Cloud", "Gaming", "V1"]
                parent_config = while namespace.any?
                                  parent_name = namespace.join "::"
                                  parent_const = const_get parent_name
                                  break parent_const.configure if parent_const.respond_to? :configure
                                  namespace.pop
                                end
                default_config = Client::Configuration.new parent_config

                default_config.rpcs.list_game_server_clusters.timeout = 60.0
                default_config.rpcs.list_game_server_clusters.retry_policy = {
                  initial_delay: 1.0,
                  max_delay: 10.0,
                  multiplier: 1.3,
                  retry_codes: [14]
                }

                default_config.rpcs.get_game_server_cluster.timeout = 60.0
                default_config.rpcs.get_game_server_cluster.retry_policy = {
                  initial_delay: 1.0,
                  max_delay: 10.0,
                  multiplier: 1.3,
                  retry_codes: [14]
                }

                default_config.rpcs.create_game_server_cluster.timeout = 120.0

                default_config.rpcs.preview_create_game_server_cluster.timeout = 60.0
                default_config.rpcs.preview_create_game_server_cluster.retry_policy = {
                  initial_delay: 1.0,
                  max_delay: 10.0,
                  multiplier: 1.3,
                  retry_codes: [14]
                }

                default_config.rpcs.delete_game_server_cluster.timeout = 60.0

                default_config.rpcs.preview_delete_game_server_cluster.timeout = 60.0
                default_config.rpcs.preview_delete_game_server_cluster.retry_policy = {
                  initial_delay: 1.0,
                  max_delay: 10.0,
                  multiplier: 1.3,
                  retry_codes: [14]
                }

                default_config.rpcs.update_game_server_cluster.timeout = 60.0

                default_config.rpcs.preview_update_game_server_cluster.timeout = 60.0
                default_config.rpcs.preview_update_game_server_cluster.retry_policy = {
                  initial_delay: 1.0,
                  max_delay: 10.0,
                  multiplier: 1.3,
                  retry_codes: [14]
                }

                default_config
              end
              yield @configure if block_given?
              @configure
            end

            ##
            # Configure the GameServerClustersService Client instance.
            #
            # The configuration is set to the derived mode, meaning that values can be changed,
            # but structural changes (adding new fields, etc.) are not allowed. Structural changes
            # should be made on {Client.configure}.
            #
            # See {::Google::Cloud::Gaming::V1::GameServerClustersService::Client::Configuration}
            # for a description of the configuration fields.
            #
            # @yield [config] Configure the Client client.
            # @yieldparam config [Client::Configuration]
            #
            # @return [Client::Configuration]
            #
            def configure
              yield @config if block_given?
              @config
            end

            ##
            # Create a new GameServerClustersService client object.
            #
            # ## Examples
            #
            # To create a new GameServerClustersService client with the default
            # configuration:
            #
            #     client = ::Google::Cloud::Gaming::V1::GameServerClustersService::Client.new
            #
            # To create a new GameServerClustersService client with a custom
            # configuration:
            #
            #     client = ::Google::Cloud::Gaming::V1::GameServerClustersService::Client.new do |config|
            #       config.timeout = 10.0
            #     end
            #
            # @yield [config] Configure the GameServerClustersService client.
            # @yieldparam config [Client::Configuration]
            #
            def initialize
              # These require statements are intentionally placed here to initialize
              # the gRPC module only when it's required.
              # See https://github.com/googleapis/toolkit/issues/446
              require "gapic/grpc"
              require "google/cloud/gaming/v1/game_server_clusters_service_services_pb"

              # Create the configuration object
              @config = Configuration.new Client.configure

              # Yield the configuration if needed
              yield @config if block_given?

              # Create credentials
              credentials = @config.credentials
              # Use self-signed JWT if the scope and endpoint are unchanged from default,
              # but only if the default endpoint does not have a region prefix.
              enable_self_signed_jwt = @config.scope == Client.configure.scope &&
                                       @config.endpoint == Client.configure.endpoint &&
                                       !@config.endpoint.split(".").first.include?("-")
              credentials ||= Credentials.default scope: @config.scope,
                                                  enable_self_signed_jwt: enable_self_signed_jwt
              if credentials.is_a?(String) || credentials.is_a?(Hash)
                credentials = Credentials.new credentials, scope: @config.scope
              end
              @quota_project_id = @config.quota_project
              @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

              @operations_client = Operations.new do |config|
                config.credentials = credentials
                config.endpoint = @config.endpoint
              end

              @game_server_clusters_service_stub = ::Gapic::ServiceStub.new(
                ::Google::Cloud::Gaming::V1::GameServerClustersService::Stub,
                credentials:  credentials,
                endpoint:     @config.endpoint,
                channel_args: @config.channel_args,
                interceptors: @config.interceptors
              )
            end

            ##
            # Get the associated client for long-running operations.
            #
            # @return [::Google::Cloud::Gaming::V1::GameServerClustersService::Operations]
            #
            attr_reader :operations_client

            # Service calls

            ##
            # Lists game server clusters in a given project and location.
            #
            # @overload list_game_server_clusters(request, options = nil)
            #   Pass arguments to `list_game_server_clusters` via a request object, either of type
            #   {::Google::Cloud::Gaming::V1::ListGameServerClustersRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::Gaming::V1::ListGameServerClustersRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload list_game_server_clusters(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil)
            #   Pass arguments to `list_game_server_clusters` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param parent [::String]
            #     Required. The parent resource name. Uses the form:
            #     "projects/\\{project}/locations/\\{location}/realms/\\{realm}".
            #   @param page_size [::Integer]
            #     Optional. The maximum number of items to return.  If unspecified, the server
            #     will pick an appropriate default. The server may return fewer items than
            #     requested. A caller should only rely on response's
            #     {::Google::Cloud::Gaming::V1::ListGameServerClustersResponse#next_page_token next_page_token} to
            #     determine if there are more GameServerClusters left to be queried.
            #   @param page_token [::String]
            #     Optional. The next_page_token value returned from a previous List request, if any.
            #   @param filter [::String]
            #     Optional. The filter to apply to list results.
            #   @param order_by [::String]
            #     Optional. Specifies the ordering of results following syntax at
            #     https://cloud.google.com/apis/design/design_patterns#sorting_order.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Gapic::PagedEnumerable<::Google::Cloud::Gaming::V1::GameServerCluster>]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Gapic::PagedEnumerable<::Google::Cloud::Gaming::V1::GameServerCluster>]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def list_game_server_clusters request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Gaming::V1::ListGameServerClustersRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.list_game_server_clusters.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::Gaming::V1::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "parent" => request.parent
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.list_game_server_clusters.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.list_game_server_clusters.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @game_server_clusters_service_stub.call_rpc :list_game_server_clusters, request, options: options do |response, operation|
                response = ::Gapic::PagedEnumerable.new @game_server_clusters_service_stub, :list_game_server_clusters, request, response, operation, options
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Gets details of a single game server cluster.
            #
            # @overload get_game_server_cluster(request, options = nil)
            #   Pass arguments to `get_game_server_cluster` via a request object, either of type
            #   {::Google::Cloud::Gaming::V1::GetGameServerClusterRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::Gaming::V1::GetGameServerClusterRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload get_game_server_cluster(name: nil)
            #   Pass arguments to `get_game_server_cluster` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param name [::String]
            #     Required. The name of the game server cluster to retrieve. Uses the form:
            #
            #     `projects/{project}/locations/{location}/realms/{realm-id}/gameServerClusters/{cluster}`.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Google::Cloud::Gaming::V1::GameServerCluster]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Google::Cloud::Gaming::V1::GameServerCluster]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def get_game_server_cluster request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Gaming::V1::GetGameServerClusterRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.get_game_server_cluster.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::Gaming::V1::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "name" => request.name
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.get_game_server_cluster.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.get_game_server_cluster.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @game_server_clusters_service_stub.call_rpc :get_game_server_cluster, request, options: options do |response, operation|
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Creates a new game server cluster in a given project and location.
            #
            # @overload create_game_server_cluster(request, options = nil)
            #   Pass arguments to `create_game_server_cluster` via a request object, either of type
            #   {::Google::Cloud::Gaming::V1::CreateGameServerClusterRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::Gaming::V1::CreateGameServerClusterRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload create_game_server_cluster(parent: nil, game_server_cluster_id: nil, game_server_cluster: nil)
            #   Pass arguments to `create_game_server_cluster` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param parent [::String]
            #     Required. The parent resource name. Uses the form:
            #     `projects/{project}/locations/{location}/realms/{realm-id}`.
            #   @param game_server_cluster_id [::String]
            #     Required. The ID of the game server cluster resource to be created.
            #   @param game_server_cluster [::Google::Cloud::Gaming::V1::GameServerCluster, ::Hash]
            #     Required. The game server cluster resource to be created.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Gapic::Operation]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Gapic::Operation]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def create_game_server_cluster request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Gaming::V1::CreateGameServerClusterRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.create_game_server_cluster.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::Gaming::V1::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "parent" => request.parent
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.create_game_server_cluster.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.create_game_server_cluster.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @game_server_clusters_service_stub.call_rpc :create_game_server_cluster, request, options: options do |response, operation|
                response = ::Gapic::Operation.new response, @operations_client, options: options
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Previews creation of a new game server cluster in a given project and
            # location.
            #
            # @overload preview_create_game_server_cluster(request, options = nil)
            #   Pass arguments to `preview_create_game_server_cluster` via a request object, either of type
            #   {::Google::Cloud::Gaming::V1::PreviewCreateGameServerClusterRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::Gaming::V1::PreviewCreateGameServerClusterRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload preview_create_game_server_cluster(parent: nil, game_server_cluster_id: nil, game_server_cluster: nil, preview_time: nil)
            #   Pass arguments to `preview_create_game_server_cluster` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param parent [::String]
            #     Required. The parent resource name. Uses the form:
            #     `projects/{project}/locations/{location}/realms/{realm}`.
            #   @param game_server_cluster_id [::String]
            #     Required. The ID of the game server cluster resource to be created.
            #   @param game_server_cluster [::Google::Cloud::Gaming::V1::GameServerCluster, ::Hash]
            #     Required. The game server cluster resource to be created.
            #   @param preview_time [::Google::Protobuf::Timestamp, ::Hash]
            #     Optional. The target timestamp to compute the preview.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Google::Cloud::Gaming::V1::PreviewCreateGameServerClusterResponse]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Google::Cloud::Gaming::V1::PreviewCreateGameServerClusterResponse]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def preview_create_game_server_cluster request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Gaming::V1::PreviewCreateGameServerClusterRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.preview_create_game_server_cluster.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::Gaming::V1::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "parent" => request.parent
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.preview_create_game_server_cluster.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.preview_create_game_server_cluster.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @game_server_clusters_service_stub.call_rpc :preview_create_game_server_cluster, request, options: options do |response, operation|
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Deletes a single game server cluster.
            #
            # @overload delete_game_server_cluster(request, options = nil)
            #   Pass arguments to `delete_game_server_cluster` via a request object, either of type
            #   {::Google::Cloud::Gaming::V1::DeleteGameServerClusterRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::Gaming::V1::DeleteGameServerClusterRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload delete_game_server_cluster(name: nil)
            #   Pass arguments to `delete_game_server_cluster` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param name [::String]
            #     Required. The name of the game server cluster to delete. Uses the form:
            #     `projects/{project}/locations/{location}/gameServerClusters/{cluster}`.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Gapic::Operation]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Gapic::Operation]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def delete_game_server_cluster request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Gaming::V1::DeleteGameServerClusterRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.delete_game_server_cluster.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::Gaming::V1::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "name" => request.name
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.delete_game_server_cluster.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.delete_game_server_cluster.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @game_server_clusters_service_stub.call_rpc :delete_game_server_cluster, request, options: options do |response, operation|
                response = ::Gapic::Operation.new response, @operations_client, options: options
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Previews deletion of a single game server cluster.
            #
            # @overload preview_delete_game_server_cluster(request, options = nil)
            #   Pass arguments to `preview_delete_game_server_cluster` via a request object, either of type
            #   {::Google::Cloud::Gaming::V1::PreviewDeleteGameServerClusterRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::Gaming::V1::PreviewDeleteGameServerClusterRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload preview_delete_game_server_cluster(name: nil, preview_time: nil)
            #   Pass arguments to `preview_delete_game_server_cluster` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param name [::String]
            #     Required. The name of the game server cluster to delete. Uses the form:
            #     `projects/{project}/locations/{location}/gameServerClusters/{cluster}`.
            #   @param preview_time [::Google::Protobuf::Timestamp, ::Hash]
            #     Optional. The target timestamp to compute the preview.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Google::Cloud::Gaming::V1::PreviewDeleteGameServerClusterResponse]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Google::Cloud::Gaming::V1::PreviewDeleteGameServerClusterResponse]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def preview_delete_game_server_cluster request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Gaming::V1::PreviewDeleteGameServerClusterRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.preview_delete_game_server_cluster.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::Gaming::V1::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "name" => request.name
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.preview_delete_game_server_cluster.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.preview_delete_game_server_cluster.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @game_server_clusters_service_stub.call_rpc :preview_delete_game_server_cluster, request, options: options do |response, operation|
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Patches a single game server cluster.
            #
            # @overload update_game_server_cluster(request, options = nil)
            #   Pass arguments to `update_game_server_cluster` via a request object, either of type
            #   {::Google::Cloud::Gaming::V1::UpdateGameServerClusterRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::Gaming::V1::UpdateGameServerClusterRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload update_game_server_cluster(game_server_cluster: nil, update_mask: nil)
            #   Pass arguments to `update_game_server_cluster` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param game_server_cluster [::Google::Cloud::Gaming::V1::GameServerCluster, ::Hash]
            #     Required. The game server cluster to be updated.
            #     Only fields specified in update_mask are updated.
            #   @param update_mask [::Google::Protobuf::FieldMask, ::Hash]
            #     Required. Mask of fields to update. At least one path must be supplied in
            #     this field. For the `FieldMask` definition, see
            #
            #     https:
            #     //developers.google.com/protocol-buffers
            #     // /docs/reference/google.protobuf#fieldmask
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Gapic::Operation]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Gapic::Operation]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def update_game_server_cluster request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Gaming::V1::UpdateGameServerClusterRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.update_game_server_cluster.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::Gaming::V1::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "game_server_cluster.name" => request.game_server_cluster.name
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.update_game_server_cluster.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.update_game_server_cluster.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @game_server_clusters_service_stub.call_rpc :update_game_server_cluster, request, options: options do |response, operation|
                response = ::Gapic::Operation.new response, @operations_client, options: options
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Previews updating a GameServerCluster.
            #
            # @overload preview_update_game_server_cluster(request, options = nil)
            #   Pass arguments to `preview_update_game_server_cluster` via a request object, either of type
            #   {::Google::Cloud::Gaming::V1::PreviewUpdateGameServerClusterRequest} or an equivalent Hash.
            #
            #   @param request [::Google::Cloud::Gaming::V1::PreviewUpdateGameServerClusterRequest, ::Hash]
            #     A request object representing the call parameters. Required. To specify no
            #     parameters, or to keep all the default parameter values, pass an empty Hash.
            #   @param options [::Gapic::CallOptions, ::Hash]
            #     Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.
            #
            # @overload preview_update_game_server_cluster(game_server_cluster: nil, update_mask: nil, preview_time: nil)
            #   Pass arguments to `preview_update_game_server_cluster` via keyword arguments. Note that at
            #   least one keyword argument is required. To specify no parameters, or to keep all
            #   the default parameter values, pass an empty Hash as a request object (see above).
            #
            #   @param game_server_cluster [::Google::Cloud::Gaming::V1::GameServerCluster, ::Hash]
            #     Required. The game server cluster to be updated.
            #     Only fields specified in update_mask are updated.
            #   @param update_mask [::Google::Protobuf::FieldMask, ::Hash]
            #     Required. Mask of fields to update. At least one path must be supplied in
            #     this field. For the `FieldMask` definition, see
            #
            #     https:
            #     //developers.google.com/protocol-buffers
            #     // /docs/reference/google.protobuf#fieldmask
            #   @param preview_time [::Google::Protobuf::Timestamp, ::Hash]
            #     Optional. The target timestamp to compute the preview.
            #
            # @yield [response, operation] Access the result along with the RPC operation
            # @yieldparam response [::Google::Cloud::Gaming::V1::PreviewUpdateGameServerClusterResponse]
            # @yieldparam operation [::GRPC::ActiveCall::Operation]
            #
            # @return [::Google::Cloud::Gaming::V1::PreviewUpdateGameServerClusterResponse]
            #
            # @raise [::Google::Cloud::Error] if the RPC is aborted.
            #
            def preview_update_game_server_cluster request, options = nil
              raise ::ArgumentError, "request must be provided" if request.nil?

              request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Gaming::V1::PreviewUpdateGameServerClusterRequest

              # Converts hash and nil to an options object
              options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

              # Customize the options with defaults
              metadata = @config.rpcs.preview_update_game_server_cluster.metadata.to_h

              # Set x-goog-api-client and x-goog-user-project headers
              metadata[:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
                lib_name: @config.lib_name, lib_version: @config.lib_version,
                gapic_version: ::Google::Cloud::Gaming::V1::VERSION
              metadata[:"x-goog-user-project"] = @quota_project_id if @quota_project_id

              header_params = {
                "game_server_cluster.name" => request.game_server_cluster.name
              }
              request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
              metadata[:"x-goog-request-params"] ||= request_params_header

              options.apply_defaults timeout:      @config.rpcs.preview_update_game_server_cluster.timeout,
                                     metadata:     metadata,
                                     retry_policy: @config.rpcs.preview_update_game_server_cluster.retry_policy
              options.apply_defaults metadata:     @config.metadata,
                                     retry_policy: @config.retry_policy

              @game_server_clusters_service_stub.call_rpc :preview_update_game_server_cluster, request, options: options do |response, operation|
                yield response, operation if block_given?
                return response
              end
            rescue ::GRPC::BadStatus => e
              raise ::Google::Cloud::Error.from_error(e)
            end

            ##
            # Configuration class for the GameServerClustersService API.
            #
            # This class represents the configuration for GameServerClustersService,
            # providing control over timeouts, retry behavior, logging, transport
            # parameters, and other low-level controls. Certain parameters can also be
            # applied individually to specific RPCs. See
            # {::Google::Cloud::Gaming::V1::GameServerClustersService::Client::Configuration::Rpcs}
            # for a list of RPCs that can be configured independently.
            #
            # Configuration can be applied globally to all clients, or to a single client
            # on construction.
            #
            # # Examples
            #
            # To modify the global config, setting the timeout for list_game_server_clusters
            # to 20 seconds, and all remaining timeouts to 10 seconds:
            #
            #     ::Google::Cloud::Gaming::V1::GameServerClustersService::Client.configure do |config|
            #       config.timeout = 10.0
            #       config.rpcs.list_game_server_clusters.timeout = 20.0
            #     end
            #
            # To apply the above configuration only to a new client:
            #
            #     client = ::Google::Cloud::Gaming::V1::GameServerClustersService::Client.new do |config|
            #       config.timeout = 10.0
            #       config.rpcs.list_game_server_clusters.timeout = 20.0
            #     end
            #
            # @!attribute [rw] endpoint
            #   The hostname or hostname:port of the service endpoint.
            #   Defaults to `"gameservices.googleapis.com"`.
            #   @return [::String]
            # @!attribute [rw] credentials
            #   Credentials to send with calls. You may provide any of the following types:
            #    *  (`String`) The path to a service account key file in JSON format
            #    *  (`Hash`) A service account key as a Hash
            #    *  (`Google::Auth::Credentials`) A googleauth credentials object
            #       (see the [googleauth docs](https://googleapis.dev/ruby/googleauth/latest/index.html))
            #    *  (`Signet::OAuth2::Client`) A signet oauth2 client object
            #       (see the [signet docs](https://googleapis.dev/ruby/signet/latest/Signet/OAuth2/Client.html))
            #    *  (`GRPC::Core::Channel`) a gRPC channel with included credentials
            #    *  (`GRPC::Core::ChannelCredentials`) a gRPC credentails object
            #    *  (`nil`) indicating no credentials
            #   @return [::Object]
            # @!attribute [rw] scope
            #   The OAuth scopes
            #   @return [::Array<::String>]
            # @!attribute [rw] lib_name
            #   The library name as recorded in instrumentation and logging
            #   @return [::String]
            # @!attribute [rw] lib_version
            #   The library version as recorded in instrumentation and logging
            #   @return [::String]
            # @!attribute [rw] channel_args
            #   Extra parameters passed to the gRPC channel. Note: this is ignored if a
            #   `GRPC::Core::Channel` object is provided as the credential.
            #   @return [::Hash]
            # @!attribute [rw] interceptors
            #   An array of interceptors that are run before calls are executed.
            #   @return [::Array<::GRPC::ClientInterceptor>]
            # @!attribute [rw] timeout
            #   The call timeout in seconds.
            #   @return [::Numeric]
            # @!attribute [rw] metadata
            #   Additional gRPC headers to be sent with the call.
            #   @return [::Hash{::Symbol=>::String}]
            # @!attribute [rw] retry_policy
            #   The retry policy. The value is a hash with the following keys:
            #    *  `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
            #    *  `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
            #    *  `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
            #    *  `:retry_codes` (*type:* `Array<String>`) - The error codes that should
            #       trigger a retry.
            #   @return [::Hash]
            # @!attribute [rw] quota_project
            #   A separate project against which to charge quota.
            #   @return [::String]
            #
            class Configuration
              extend ::Gapic::Config

              config_attr :endpoint,      "gameservices.googleapis.com", ::String
              config_attr :credentials,   nil do |value|
                allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil]
                allowed += [::GRPC::Core::Channel, ::GRPC::Core::ChannelCredentials] if defined? ::GRPC
                allowed.any? { |klass| klass === value }
              end
              config_attr :scope,         nil, ::String, ::Array, nil
              config_attr :lib_name,      nil, ::String, nil
              config_attr :lib_version,   nil, ::String, nil
              config_attr(:channel_args,  { "grpc.service_config_disable_resolution" => 1 }, ::Hash, nil)
              config_attr :interceptors,  nil, ::Array, nil
              config_attr :timeout,       nil, ::Numeric, nil
              config_attr :metadata,      nil, ::Hash, nil
              config_attr :retry_policy,  nil, ::Hash, ::Proc, nil
              config_attr :quota_project, nil, ::String, nil

              # @private
              def initialize parent_config = nil
                @parent_config = parent_config unless parent_config.nil?

                yield self if block_given?
              end

              ##
              # Configurations for individual RPCs
              # @return [Rpcs]
              #
              def rpcs
                @rpcs ||= begin
                  parent_rpcs = nil
                  parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs)
                  Rpcs.new parent_rpcs
                end
              end

              ##
              # Configuration RPC class for the GameServerClustersService API.
              #
              # Includes fields providing the configuration for each RPC in this service.
              # Each configuration object is of type `Gapic::Config::Method` and includes
              # the following configuration fields:
              #
              #  *  `timeout` (*type:* `Numeric`) - The call timeout in seconds
              #  *  `metadata` (*type:* `Hash{Symbol=>String}`) - Additional gRPC headers
              #  *  `retry_policy (*type:* `Hash`) - The retry policy. The policy fields
              #     include the following keys:
              #      *  `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
              #      *  `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
              #      *  `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
              #      *  `:retry_codes` (*type:* `Array<String>`) - The error codes that should
              #         trigger a retry.
              #
              class Rpcs
                ##
                # RPC-specific configuration for `list_game_server_clusters`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :list_game_server_clusters
                ##
                # RPC-specific configuration for `get_game_server_cluster`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :get_game_server_cluster
                ##
                # RPC-specific configuration for `create_game_server_cluster`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :create_game_server_cluster
                ##
                # RPC-specific configuration for `preview_create_game_server_cluster`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :preview_create_game_server_cluster
                ##
                # RPC-specific configuration for `delete_game_server_cluster`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :delete_game_server_cluster
                ##
                # RPC-specific configuration for `preview_delete_game_server_cluster`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :preview_delete_game_server_cluster
                ##
                # RPC-specific configuration for `update_game_server_cluster`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :update_game_server_cluster
                ##
                # RPC-specific configuration for `preview_update_game_server_cluster`
                # @return [::Gapic::Config::Method]
                #
                attr_reader :preview_update_game_server_cluster

                # @private
                def initialize parent_rpcs = nil
                  list_game_server_clusters_config = parent_rpcs.list_game_server_clusters if parent_rpcs.respond_to? :list_game_server_clusters
                  @list_game_server_clusters = ::Gapic::Config::Method.new list_game_server_clusters_config
                  get_game_server_cluster_config = parent_rpcs.get_game_server_cluster if parent_rpcs.respond_to? :get_game_server_cluster
                  @get_game_server_cluster = ::Gapic::Config::Method.new get_game_server_cluster_config
                  create_game_server_cluster_config = parent_rpcs.create_game_server_cluster if parent_rpcs.respond_to? :create_game_server_cluster
                  @create_game_server_cluster = ::Gapic::Config::Method.new create_game_server_cluster_config
                  preview_create_game_server_cluster_config = parent_rpcs.preview_create_game_server_cluster if parent_rpcs.respond_to? :preview_create_game_server_cluster
                  @preview_create_game_server_cluster = ::Gapic::Config::Method.new preview_create_game_server_cluster_config
                  delete_game_server_cluster_config = parent_rpcs.delete_game_server_cluster if parent_rpcs.respond_to? :delete_game_server_cluster
                  @delete_game_server_cluster = ::Gapic::Config::Method.new delete_game_server_cluster_config
                  preview_delete_game_server_cluster_config = parent_rpcs.preview_delete_game_server_cluster if parent_rpcs.respond_to? :preview_delete_game_server_cluster
                  @preview_delete_game_server_cluster = ::Gapic::Config::Method.new preview_delete_game_server_cluster_config
                  update_game_server_cluster_config = parent_rpcs.update_game_server_cluster if parent_rpcs.respond_to? :update_game_server_cluster
                  @update_game_server_cluster = ::Gapic::Config::Method.new update_game_server_cluster_config
                  preview_update_game_server_cluster_config = parent_rpcs.preview_update_game_server_cluster if parent_rpcs.respond_to? :preview_update_game_server_cluster
                  @preview_update_game_server_cluster = ::Gapic::Config::Method.new preview_update_game_server_cluster_config

                  yield self if block_given?
                end
              end
            end
          end
        end
      end
    end
  end
end
