# frozen_string_literal: true

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Auto-generated by gapic-generator-ruby. DO NOT EDIT!


module Google
  module Cloud
    module Gaming
      module V1
        # Request message for GameServerConfigsService.ListGameServerConfigs.
        # @!attribute [rw] parent
        #   @return [::String]
        #     Required. The parent resource name. Uses the form:
        #
        #     `projects/{project}/locations/{location}/gameServerDeployments/{deployment}/configs/*`.
        # @!attribute [rw] page_size
        #   @return [::Integer]
        #     Optional. The maximum number of items to return.  If unspecified, server
        #     will pick an appropriate default. Server may return fewer items than
        #     requested. A caller should only rely on response's
        #     {::Google::Cloud::Gaming::V1::ListGameServerConfigsResponse#next_page_token next_page_token} to
        #     determine if there are more GameServerConfigs left to be queried.
        # @!attribute [rw] page_token
        #   @return [::String]
        #     Optional. The next_page_token value returned from a previous list request, if any.
        # @!attribute [rw] filter
        #   @return [::String]
        #     Optional. The filter to apply to list results.
        # @!attribute [rw] order_by
        #   @return [::String]
        #     Optional. Specifies the ordering of results following syntax at
        #     https://cloud.google.com/apis/design/design_patterns#sorting_order.
        class ListGameServerConfigsRequest
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods
        end

        # Response message for GameServerConfigsService.ListGameServerConfigs.
        # @!attribute [rw] game_server_configs
        #   @return [::Array<::Google::Cloud::Gaming::V1::GameServerConfig>]
        #     The list of game server configs.
        # @!attribute [rw] next_page_token
        #   @return [::String]
        #     Token to retrieve the next page of results, or empty if there are no more
        #     results in the list.
        # @!attribute [rw] unreachable
        #   @return [::Array<::String>]
        #     List of locations that could not be reached.
        class ListGameServerConfigsResponse
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods
        end

        # Request message for GameServerConfigsService.GetGameServerConfig.
        # @!attribute [rw] name
        #   @return [::String]
        #     Required. The name of the game server config to retrieve. Uses the form:
        #
        #     `projects/{project}/locations/{location}/gameServerDeployments/{deployment}/configs/{config}`.
        class GetGameServerConfigRequest
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods
        end

        # Request message for GameServerConfigsService.CreateGameServerConfig.
        # @!attribute [rw] parent
        #   @return [::String]
        #     Required. The parent resource name. Uses the form:
        #
        #     `projects/{project}/locations/{location}/gameServerDeployments/{deployment}/`.
        # @!attribute [rw] config_id
        #   @return [::String]
        #     Required. The ID of the game server config resource to be created.
        # @!attribute [rw] game_server_config
        #   @return [::Google::Cloud::Gaming::V1::GameServerConfig]
        #     Required. The game server config resource to be created.
        class CreateGameServerConfigRequest
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods
        end

        # Request message for GameServerConfigsService.DeleteGameServerConfig.
        # @!attribute [rw] name
        #   @return [::String]
        #     Required. The name of the game server config to delete. Uses the form:
        #
        #     `projects/{project}/locations/{location}/gameServerDeployments/{deployment}/configs/{config}`.
        class DeleteGameServerConfigRequest
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods
        end

        # Autoscaling config for an Agones fleet.
        # @!attribute [rw] name
        #   @return [::String]
        #     Required. The name of the Scaling Config
        # @!attribute [rw] fleet_autoscaler_spec
        #   @return [::String]
        #     Required. Agones fleet autoscaler spec. Example spec:
        #     https://agones.dev/site/docs/reference/fleetautoscaler/
        # @!attribute [rw] selectors
        #   @return [::Array<::Google::Cloud::Gaming::V1::LabelSelector>]
        #     Labels used to identify the game server clusters to which this Agones
        #     scaling config applies. A game server cluster is subject to this Agones
        #     scaling config if its labels match any of the selector entries.
        # @!attribute [rw] schedules
        #   @return [::Array<::Google::Cloud::Gaming::V1::Schedule>]
        #     The schedules to which this Scaling Config applies.
        class ScalingConfig
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods
        end

        # Fleet configs for Agones.
        # @!attribute [rw] fleet_spec
        #   @return [::String]
        #     Agones fleet spec. Example spec:
        #     `https://agones.dev/site/docs/reference/fleet/`.
        # @!attribute [rw] name
        #   @return [::String]
        #     The name of the FleetConfig.
        class FleetConfig
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods
        end

        # A game server config resource.
        # @!attribute [rw] name
        #   @return [::String]
        #     The resource name of the game server config. Uses the form:
        #
        #     `projects/{project}/locations/{location}/gameServerDeployments/{deployment}/configs/{config}`.
        #     For example,
        #
        #     `projects/my-project/locations/global/gameServerDeployments/my-game/configs/my-config`.
        # @!attribute [r] create_time
        #   @return [::Google::Protobuf::Timestamp]
        #     Output only. The creation time.
        # @!attribute [r] update_time
        #   @return [::Google::Protobuf::Timestamp]
        #     Output only. The last-modified time.
        # @!attribute [rw] labels
        #   @return [::Google::Protobuf::Map{::String => ::String}]
        #     The labels associated with this game server config. Each label is a
        #     key-value pair.
        # @!attribute [rw] fleet_configs
        #   @return [::Array<::Google::Cloud::Gaming::V1::FleetConfig>]
        #     FleetConfig contains a list of Agones fleet specs. Only one FleetConfig
        #     is allowed.
        # @!attribute [rw] scaling_configs
        #   @return [::Array<::Google::Cloud::Gaming::V1::ScalingConfig>]
        #     The autoscaling settings.
        # @!attribute [rw] description
        #   @return [::String]
        #     The description of the game server config.
        class GameServerConfig
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods

          # @!attribute [rw] key
          #   @return [::String]
          # @!attribute [rw] value
          #   @return [::String]
          class LabelsEntry
            include ::Google::Protobuf::MessageExts
            extend ::Google::Protobuf::MessageExts::ClassMethods
          end
        end
      end
    end
  end
end
